@@ -43,13 +43,13 @@ parseOM <- function(obj, sos, verbose = FALSE) {
 	
 	.parsingFunction <- sosParsers(sos)[[.rootName]]
 	if(!is.null(.parsingFunction)) {
-		if(verbose) cat("* Parsing O&M", .rootName, "\n") #, "with: "); print(.parsingFunction)
+		if(verbose) cat("[parseOM] rootName is", .rootName, "\n") #, "with: "); print(.parsingFunction)
 		.om <- .parsingFunction(obj = .root, sos = sos, verbose = verbose)
-		if(verbose) cat("* Done Parsing", .rootName, ":",
+		if(verbose) cat("[parseOM] Done!", .rootName, ":",
 					substr(toString(.om), 0, 74), "...\n")
 	}
 	else {
-		warning(paste("No parsing function for given element ", .rootName))
+		warning(paste("[parseOM] No parsing function for given element", .rootName))
 	}
 	
 	return(.om)
@@ -65,21 +65,23 @@ parseObservationProperty <- function(obj, sos, verbose = FALSE) {
 		.child <- .noneTexts[[1]]
 		#.child <- xmlChildren(obj)[[1]]
 		if(verbose) {
-			cat("Parsing child of member:", xmlName(.child), "\n")
+			cat("[parseObservationProperty] Parsing child of member:",
+					xmlName(.child), "\n")
 		}
 		.mResult <- parseOM(.child, sos, verbose)
 	}
 	else {
 		# no child, try href attribute
-		if(verbose) cat("Member has no direct child!\n")
+		if(verbose) cat("[parseObservationProperty] Member has no direct child!\n")
 		
 		.href <- xmlGetAttr(node = obj, name = "href", default = NA_character_)
 		if(!is.na(.href)) {
+			warning(paste("[parseObservationProperty] Only reference to Observation was returned:",
+					.href))
 			.mResult <- OmObservationProperty(href = .href)
-			warning("Only reference to Observation was returned!")
 		}
 		else {
-			warning("No Observation found in response!")
+			warning("[parseObservationProperty] No Observation found in response!")
 			.mResult <- OmObservationProperty()
 		}
 	}
@@ -91,9 +93,10 @@ parseObservationProperty <- function(obj, sos, verbose = FALSE) {
 # om:Measurement
 #
 parseMeasurement <- function(obj, sos, verbose = FALSE) {
+	if(verbose) cat("[parseMeasurement]\n")
 	
 	.samplingTime <- parseSamplingTime(obj = obj[[omSamplingTimeName]],
-			format = sosTimeFormat(sos))
+			format = sosTimeFormat(sos), verbose = verbose)
 	
 	# 52N SOS only returns om:Measurements (!) with procedure ids and observed 
 	# properties in xlink:href
@@ -102,7 +105,8 @@ parseMeasurement <- function(obj, sos, verbose = FALSE) {
 			href = xmlGetAttr(node = obj[[omObservedPropertyName]],
 					name = "href"))
 	
-	.featureOfInterest <- parseFOI(obj[[omFeatureOfInterestName]], sos = sos)
+	.featureOfInterest <- parseFOI(obj[[omFeatureOfInterestName]], sos = sos,
+			verbose = verbose)
 	
 	# must be GmlMeasure
 	.result <- parseMeasure(obj[[omResultName]])
@@ -124,6 +128,10 @@ parseMeasurement <- function(obj, sos, verbose = FALSE) {
 # om:Observation
 #
 parseObservation <- function(obj, sos, verbose = FALSE) {
+	.id <- xmlGetAttr(node = obj, name = "id",
+			default = NA_character_)
+	if(verbose) cat("[parseObservation]", .id, "\n")
+	
 	# 52N SOS only returns om:Observation with procedure ids xlink:href
 	.procedure <- xmlGetAttr(node = obj[[omProcedureName]], name = "href",
 			default = NA_character_)
@@ -133,7 +141,7 @@ parseObservation <- function(obj, sos, verbose = FALSE) {
 	
 	if(!is.null(obj[[omSamplingTimeName]])) {
 		.samplingTime <- parseSamplingTime(obj = obj[[omSamplingTimeName]],
-				format = sosTimeFormat(sos = sos))
+				format = sosTimeFormat(sos = sos), verbose = verbose)
 	} else {
 		warning("om:samplingTime is mandatory in om:Observation, but is missing!")
 		.samplingTime <- NULL
@@ -141,7 +149,7 @@ parseObservation <- function(obj, sos, verbose = FALSE) {
 	
 	if(!is.null(obj[[omFeatureOfInterestName]])) {
 		.featureOfInterest <- parseFOI(obj[[omFeatureOfInterestName]],
-				sos = sos)
+				sos = sos, verbose = verbose)
 	} else {
 		warning("om:featureOfInterest is mandatory in om:Observation, but is missing!")
 		.featureOfInterest <- NULL
@@ -154,7 +162,7 @@ parseObservation <- function(obj, sos, verbose = FALSE) {
 	# optional elements
 	if(!is.null(obj[[omResultTimeName]])) {
 		.resultTime <- parseSamplingTime(obj = obj[[omResultTimeName]],
-				format = sosTimeFormat(sos = sos))
+				format = sosTimeFormat(sos = sos), verbose = verbose)
 	}
 	else {
 		.resultTime <- NULL
@@ -180,7 +188,7 @@ parseObservationCollection <- function(obj, sos, verbose) {
 	# remove nodes other than member
 	.members <- .filterXmlChildren(obj, omMemberName, includeNamed = TRUE)
 	
-	if(verbose) cat("Parsing ObservationCollection with ", length(.members), 
+	if(verbose) cat("[parseObservationCollection] with ", length(.members), 
 				"element(s).\n")
 	
 	.env <- obj[[gmlBoundedByName]][[gmlEnvelopeName]]
@@ -190,6 +198,9 @@ parseObservationCollection <- function(obj, sos, verbose) {
 				lowerCorner = xmlValue(.env[[gmlLowerCornerName]]),
 				upperCorner = xmlValue(.env[[gmlUpperCornerName]]))
 		
+		if(verbose) cat("[parseObservationCollection] Parsed envelope:",
+					toString(.boundedBy))
+		
 		if(sosSwitchCoordinates(sos)) {
 			warning("Switching coordinates in envelope of ObservationCollection!")
 			.origLC <- strsplit(x = .boundedBy[["lowerCorner"]], split = " ")
@@ -201,6 +212,7 @@ parseObservationCollection <- function(obj, sos, verbose) {
 		}
 	}
 	else {
+		if(verbose) cat("[parseObservationCollection] Empty envelope! ")
 		.boundedBy <- list()
 	}
 	
@@ -218,7 +230,7 @@ parseObservationCollection <- function(obj, sos, verbose) {
 	}
 	
 	if(verbose)
-		cat("Parsed ObservationCollection with", length(.obsColl),
+		cat("[parseObservationCollection] Done. Processed", length(.obsColl),
 				"elements:", names(sosResult(.obsColl)), "\n")
 	
 	return(.obsColl)
@@ -228,18 +240,35 @@ parseObservationCollection <- function(obj, sos, verbose) {
 # om:result
 #
 parseResult <- function(obj, sos, verbose = FALSE) {
+	if(verbose) {
+		cat("[parseResult]\n")
+#		print(obj)
+	}
 	.result <- NULL
 	
 	.noneText <- .filterXmlChildren(node = obj, xmlTextNodeName,
-			includeNamed = FALSE)
+			includeNamed = FALSE, verbose = verbose)
+	
+	if(verbose) {
+		cat("[parseResult]", length(.noneText), " non-text nodes, names:",
+				names(.noneText), "\n")
+	}
+	
+	# Check if remaining element is there
+	if(length(.noneText) == 0) {
+		.children <- xmlChildren(obj)
+		cat("[parseResult] No non-text nodes in result, returning NULL.\n")
+		return(NULL)
+	}
+	
 	# 52N SOS currently only returns swe:DataArrayDocument, but still check
 	if(xmlName(.noneText[[1]]) != sweDataArrayName) {
-		warning(paste("Parsing of given result is NOT supported:",
+		warning(paste("[parseResult] Parsing of given result is NOT supported:",
 						xmlName(.noneText[[1]]), "-- only", sweDataArrayName,
 						"can be parsed."))
 	}
 	else {
-		if(verbose) cat("Parsing result with swe:DataArray.")
+		if(verbose) cat("[parseResult] Parsing result with swe:DataArray.\n")
 		
 		# data array parser is exchangeable
 		.dataArrayParsingFunction <- sosParsers(sos)[[sweDataArrayName]]
@@ -247,7 +276,11 @@ parseResult <- function(obj, sos, verbose = FALSE) {
 		.result <- .dataArrayParsingFunction(.dataArray, sos, verbose)
 	}
 	
-	return(.result)
+	if(is.null(.result)) {
+		stop("[parseResult] result is null! Given result:\n")
+		print(obj)
+	}
+	else return(.result)
 }
 
 
@@ -291,22 +324,26 @@ parseComplexObservation <- function(obj, sos, verbose = FALSE) {
 #
 # parse sos:featureOfInterest to according Element of GML or SA
 #
-parseFOI <- function(obj, sos) {
+parseFOI <- function(obj, sos, verbose = FALSE) {
+	if(verbose) cat("[parseFOI] starting...\n")
 	.foi <- NULL
 	
 	# has href attribute? if yes, use it!
 	.href <- xmlGetAttr(node = obj, name = "href")
 	if(!is.null(.href)) {
+		if(verbose) cat("[parseFOI] referenced FOI:", .href, "\n")
 		# feature is referenced
 		.foi <- GmlFeatureProperty(href = .href)
 	}
-	else {
+	else {		
 		# feature is available in the element
 		.noneTexts <- .filterXmlChildren(obj, xmlTextNodeName,
 				includeNamed = FALSE)
 		.feature <- .noneTexts[[1]]
 		.name <- xmlName(.feature)
 		
+		if(verbose) cat("[parseFOI] inline FOI:", .name, "\n")
+		
 		if(.name == saSamplingPointName) {
 			.sp <- parseSamplingPoint(.feature, sos = sos)
 			.foi <- GmlFeatureProperty(feature = .sp)
@@ -319,7 +356,7 @@ parseFOI <- function(obj, sos) {
 			.foi <- parseFeatureCollection(.feature, sos = sos)
 		}
 		else {
-			warning("No parsing for given feature implemented")
+			warning("[parseFOI] No parsing for given feature implemented!")
 			.foi <- GmlFeatureProperty(href = .name)
 		}
 	}
@@ -330,14 +367,18 @@ parseFOI <- function(obj, sos) {
 #
 # create according GmlTimeObject from om:samplingTime
 #
-parseSamplingTime <- function(obj, format) {
+parseSamplingTime <- function(obj, format, verbose = FALSE) {
+	if(verbose) cat("[parseSamplingTime]\n")
+	
 	.tiXML <- xmlChildren(obj)[[gmlTimeInstantName]]
 	.tpXML <- xmlChildren(obj)[[gmlTimePeriodName]]
 	.timeObject <- NULL
 	if(!is.null(.tiXML)) {
+		if(verbose) cat("[parseSamplingTime] time instant.\n")
 		.timeObject <- parseTimeInstant(obj = .tiXML, format = format)
 	}
 	else if(!is.null(.tpXML)) {
+		if(verbose) cat("[parseSamplingTime] time period.\n")
 		.timeObject <- parseTimePeriod(obj = .tpXML, format = format)
 	}
 	else {
