@@ -67,9 +67,9 @@ SOS <- function(url, method = SosDefaultConnectionMethod(),
 		
 		.sos@capabilities <- .caps
 		
-		if(verboseOutput) cat("Created new SOS:\n", toString(.sos), "\n")
+		if(verboseOutput) cat("[SOS] Created new SOS:\n", toString(.sos), "\n")
 				
-		cat("Created SOS for URL", url, "\n")
+		cat("[sos4R] Created SOS for URL", url, "\n")
 		return(.sos)
 	}
 	else stop("Service version not supported!")
@@ -395,9 +395,17 @@ setMethod(f = "getCapabilities", signature = signature(sos = "SOS_1.0.0"),
 		print(.response)
 	}
 	
-	if(saveOriginal) {
-		.filename <- paste(.cleanupFileName(procedure), "_", ".xml",
-				sep = "")
+	if(!is.null(saveOriginal)) {
+		if(is.character(saveOriginal)) {
+			.filename <- paste(saveOriginal, ".xml", sep = "")
+			if(verbose) cat("Using saveOriginal parameter for file name:",
+						.filename, "\n")
+		} 
+		else if(is.logical(saveOriginal)) {
+			if(saveOriginal) .filename <- paste(.cleanupFileName(procedure),
+						".xml", sep = "")
+			if(verbose) cat("Generating file name:", .filename, "\n")
+		}
 		
 		if(verbose) {
 			cat("[.describeSensor_1.0.0] Saving original document...",
@@ -452,9 +460,18 @@ setMethod(f = "getObservationById",
 		cat("[getObservationById] ID", observationId, "\n")
 	}
 	
-	if(saveOriginal) .filename <- paste(observationId, 
-				format(Sys.time(), sosDefaultFilenameTimeFormat),
-				sep = "_")
+	.filename <- NULL
+	if(is.character(saveOriginal)) {
+		.filename <- saveOriginal
+		if(verbose) cat("[.getObservationById_1.0.0] Using saveOriginal parameter for file name:",
+					.filename, "\n")
+	} 
+	else if(is.logical(saveOriginal)) {
+		if(saveOriginal) .filename <- paste(observationId, 
+					format(Sys.time(), sosDefaultFilenameTimeFormat),
+					sep = "_")
+		if(verbose) cat("[.getObservationById_1.0.0] Generating file name:", .filename, "\n")
+	}
 	
 	.go <- SosGetObservationById(service = sosService,
 			version = sos@version, observationId = observationId,
@@ -476,14 +493,10 @@ setMethod(f = "getObservationById",
 		print(.response)
 	}
 	
-	if(saveOriginal) {
+	if(!is.null(.filename)) {
 		.filename <- paste(.filename, ".xml", sep = "")
 		saveXML(.response, file = .filename)
-		
-		if(verbose) {
-			cat("[getObservationById] Saved original document:",
-					.filename, "\n")
-		}
+		cat("[sos4R] Original document saved:", .filename, "\n")
 	}
 	
 	if(.isExceptionReport(.response)) {
@@ -506,13 +519,9 @@ setMethod(f = "getObservationById",
 		return(.obs)
 	}
 	
-	if(saveOriginal) {
+	if(!is.null(.filename)) {
 		save(.responseString, file = .filename)
-		
-		if(verbose) {
-			cat("[getObservationById] Saved original document:",
-					.filename, "\n")
-		}
+		cat("[sos4R] Original document saved:", .filename, "\n")
 	}
 	
 	return(.responseString)
@@ -527,8 +536,18 @@ setMethod(f = "getObservationById",
 		result, resultModel, responseMode, BBOX, latest, verbose, inspect,
 		saveOriginal) {
 	
-	if(saveOriginal) .filename <- paste(.cleanupFileName(offeringId), 
-				format(Sys.time(), sosDefaultFilenameTimeFormat), sep = "_")
+	.filename <- NULL
+	if(is.character(saveOriginal)) {
+		.filename <- saveOriginal
+		if(verbose) cat("[.getObservation_1.0.0] Using saveOriginal parameter for file name:",
+					.filename, "\n")
+	} 
+	else if(is.logical(saveOriginal)) {
+		if(saveOriginal) .filename <- paste(.cleanupFileName(offeringId), 
+					format(Sys.time(), sosDefaultFilenameTimeFormat), sep = "_")
+		if(verbose) cat("[.getObservation_1.0.0] Generating file name:",
+					.filename, "\n")
+	}
 	
 	if(verbose)
 		cat("[.getObservation_1.0.0] to ", sos@url, " with offering ",
@@ -571,7 +590,7 @@ setMethod(f = "getObservationById",
 			print(.response)
 		}
 		
-		if(saveOriginal) {
+		if(!is.null(.filename)) {
 			.filename <- paste(.filename, ".xml", sep = "")
 			saveXML(.response, file = .filename)
 			
@@ -620,8 +639,8 @@ setMethod(f = "getObservationById",
 		.msg <- paste("[sos4R] Finished getObservation to", sos@url,
 				"\n\t--> received", length(.obs), "observation(s) having",
 				.countInfo , "\n")
-		if(saveOriginal) .msg <- paste(.msg, "[sos4R] Original document saved:",
-					.filename, "\n")
+		if(!is.null(.filename)) .msg <- paste(.msg,
+					"[sos4R] Original document saved:", .filename, "\n")
 		cat(.msg)
 		
 		# RETURN ###
@@ -641,7 +660,7 @@ setMethod(f = "getObservationById",
 			.parsingFunction <- sosParsers(sos)[[mimeTypeCSV]]
 			.csv <- .parsingFunction(obj = .responseString, verbose = verbose)
 		
-			if(saveOriginal) {
+			if(!is.null(.filename)) {
 				.filename <- paste(file = .filename, ".csv", sep = "")
 				write.csv(.csv, .filename)
 			}
@@ -649,7 +668,7 @@ setMethod(f = "getObservationById",
 			.msg <- paste("[sos4R] Finished getObservation to", sos@url, "\n\t",
 					"--> received observations with dimensions", 
 					toString(dim(.csv)), "\n")
-			if(saveOriginal) .msg <- paste(.msg,
+			if(!is.null(.filename)) .msg <- paste(.msg,
 						"[sos4R] Original document saved:", .filename, "\n")
 			cat(.msg)
 		
@@ -668,10 +687,11 @@ setMethod(f = "getObservationById",
 		warning("Unknown response format!")
 	}
 	
-	if(saveOriginal) {
+	if(!is.null(.filename)) {
 		save(.responseString, file = .filename)
 		cat("[sos4R] Saved original document:", .filename)
 	}
+	else warning("File name is NULL, could not save document!")
 	
 	# RETURN ##############
 	return(.responseString)
@@ -809,7 +829,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 	.optionals = ""
 	# is optional for GET
 	if( !is.na(obj@responseFormat)) {
-		if(verbose) cat("Adding response format ", obj@responseFormat, "\n")
+		if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] Adding response format ",
+					obj@responseFormat, "\n")
 		.responseFormat <- paste(
 				"responseFormat", 
 				.kvpEscapeSpecialCharacters(x = gsub(obj@responseFormat,
@@ -820,7 +841,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 	}
 	
 	if( !is.na(obj@srsName)) {
-		if(verbose) cat("Adding SRS name ", obj@srsName, "\n")
+		if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] Adding SRS name ",
+					obj@srsName, "\n")
 		.optionals <- paste(.optionals, paste("srsName", 
 						.kvpEscapeSpecialCharacters(x = obj@srsName),
 						sep = "="),
@@ -828,7 +850,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 	}
 	
 	if( !is.na(obj@eventTime)) {
-		if(verbose) cat("Adding event time", toString(obj@eventTime), "\n")
+		if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] Adding event time",
+					toString(obj@eventTime), "\n")
 		if(length(obj@eventTime) > 1)
 			warning("Only first event time in the list is used for KVP!")
 		
@@ -844,7 +867,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 					sep = "&")
 		}
 		else {
-			if(verbose) cat("encodeKVP returned NA for eventTime, omitting",
+			if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] ", 
+						"encodeKVP returned NA for eventTime, omitting",
 						"parameter for request for latest observation.")
 		}
 	}
@@ -867,7 +891,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 	}
 	
 	if( !is.na(obj@resultModel)) {
-		if(verbose) cat("Adding result model ", obj@resultModel, "\n")
+		if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] Adding result model ",
+					obj@resultModel, "\n")
 		.optionals <- paste(.optionals, paste("resultModel",
 						.kvpEscapeSpecialCharacters(x = obj@resultModel),
 						sep = "="),
@@ -875,7 +900,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 	}
 	
 	if( !is.na(obj@responseMode)) {
-		if(verbose) cat("Adding response mode ", obj@responseMode, "\n")
+		if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] Adding response mode ",
+					obj@responseMode, "\n")
 		.optionals <- paste(.optionals, paste("responseMode",
 						.kvpEscapeSpecialCharacters(x = obj@responseMode),
 						sep = "="),
@@ -883,7 +909,8 @@ setMethod("encodeRequestKVP", "SosGetObservation",
 	}
 	
 	if( !is.na(obj@BBOX)) {
-		if(verbose) cat("Adding BBOX ", obj@BBOX, "\n")
+		if(verbose) cat("[.sosEncodeRequestKVPGetObservation_1.0.0] Adding BBOX ",
+					obj@BBOX, "\n")
 		.optionals <- paste(.optionals, paste("BBOX", 
 						.kvpEscapeSpecialCharacters(x = obj@BBOX), sep = "="),
 				sep = "&")
@@ -1257,7 +1284,7 @@ setMethod(f = "checkRequest",
 				verbose = "logical"),
 		def = function(service, operation, verbose) {
 			if(verbose) {
-				cat("Checking DescribeSensor... ")
+				cat("[checkRequest] Checking DescribeSensor... ")
 			}
 			
 			# check if operation is for SOS and operation is DescribeSensor
@@ -1305,7 +1332,8 @@ setMethod(f = "checkRequest",
 				warning("Requested method type ist not listed in capablities for this operation, service might return error!")
 			
 			if(verbose) {
-				cat("Checks: procedure contained =", .procContained,
+				cat("[checkRequest] Checks: procedure contained =",
+						.procContained,
 						", output supported =", .oFSupported,
 						", method supported =", .methodSupported, "\n")
 			}
