@@ -1,7 +1,6 @@
 pkgname <- "sos4R"
 source(file.path(R.home("share"), "R", "examples-header.R"))
 options(warn = 1)
-options(pager = "console")
 library('sos4R')
 
 assign(".oldSearch", search(), pos = 'CheckExEnv')
@@ -266,6 +265,7 @@ flush(stderr()); flush(stdout())
 ###   sosTime,GmlTimeInstant-method sosTime,GmlTimeInstantProperty-method
 ###   sosTime,GmlTimePeriod-method sosTime,GmlTimePosition-method
 ###   summary.GmlTimePeriod print.summary.GmlTimePeriod
+###   sosUOM,GmlMeasure-method
 ### Keywords: classes utilities
 
 ### ** Examples
@@ -505,6 +505,7 @@ flush(stderr()); flush(stdout())
 ###   sosFeaturesOfInterest,OmMeasurement-method
 ###   sosGetCRS,OmMeasurement-method names.OmMeasurement
 ###   as.data.frame.OmMeasurement as.SpatialPointsDataFrame.OmMeasurement
+###   sosUOM,OmMeasurement-method
 ### Keywords: classes
 
 ### ** Examples
@@ -538,7 +539,8 @@ flush(stderr()); flush(stdout())
 ###   sosFeatureIds,OmObservation-method
 ###   sosObservedProperties,OmObservation-method
 ###   sosGetCRS,OmObservation-method
-###   as.SpatialPointsDataFrame.OmObservation
+###   as.SpatialPointsDataFrame.OmObservation sosUOM,OmObservation-method
+###   print.summary.OmObservation summary.OmObservation
 ### Keywords: classes
 
 ### ** Examples
@@ -590,6 +592,8 @@ flush(stderr()); flush(stdout())
 ###   sosFeaturesOfInterest,OmObservationCollection-method
 ###   as.SpatialPointsDataFrame.OmObservationCollection
 ###   sosGetCRS,OmObservationCollection-method
+###   sosUOM,OmObservationCollection-method
+###   print.summary.OmObservationCollection summary.OmObservationCollection
 ### Keywords: classes
 
 ### ** Examples
@@ -652,6 +656,7 @@ showClass("SensorML")
 ##D proc1.descr <- describeSensor(weathersos, proc1, verbose = TRUE)
 ##D plot(proc1.descr)
 ##D class(proc1.descr)
+##D print(proc1.descr
 ## End(Not run)
 
 
@@ -730,7 +735,8 @@ flush(stderr()); flush(stdout())
 ###   plot,SosObservationOffering,missing-method
 ###   as.SosObservationOffering.SpatialPolygons print.summary.SOS
 ###   print.summary.SosObservationOffering summary.SosObservationOffering
-###   summary.SOS sosResult,data.frame-method
+###   summary.SOS sosResult,data.frame-method sosUOM sosUOM,list-method
+###   sosUOM,data.frame-method
 ### Keywords: classes
 
 ### ** Examples
@@ -1079,24 +1085,6 @@ flush(stderr()); flush(stdout())
 
 
 
-cleanEx()
-nameEx("info")
-### * info
-
-flush(stderr()); flush(stdout())
-
-### Name: info
-### Title: Information retrieval functions for Sensor Observation Services
-### Aliases: info.features info.offerings info.phenomena info.sensors
-###   info.series info.sos
-### Keywords: utilities
-
-### ** Examples
-
-#TBD
-
-
-
 cleanEx()
 nameEx("parse")
 ### * parse
@@ -1289,7 +1277,8 @@ flush(stderr()); flush(stdout())
 ###   sosCreateFeatureOfInterest,ANY-method sosCreateTimeInstant
 ###   sosCreateTimeInstant-methods sosCreateTimeInstant,SOS,POSIXt-method
 ###   sosCreateTimePeriod sosCreateTimePeriod-methods
-###   sosCreateTimePeriod,SOS,POSIXt,POSIXt-method
+###   sosCreateTimePeriod,SOS,POSIXt,POSIXt-method sosCreateTime
+###   sosCreateTime-methods sosCreateTime,SOS,character-method
 ### Keywords: utilities methods
 
 ### ** Examples
@@ -1311,7 +1300,18 @@ foiBBox2 <- sosCreateFeatureOfInterest(spatialOps = bbox)
 print(foiBBox2)
 
 ## Not run: 
-##D # time examples TBD
+##D last.period <- sosCreateTimePeriod(sos = mySOS,
+##D 	begin = (Sys.time() - 3600 * 24 * 7), end = Sys.time())
+##D 
+##D oneWeek.period <- sosCreateTimePeriod(sos = mySOS,
+##D 		begin = as.POSIXct("2010/01/01"), end = as.POSIXct("2010/01/07"))
+##D oneWeek.eventTime <- sosCreateEventTimeList(oneWeek.period)
+##D 
+##D sosCreateTime(sos = mySOS, time = "2007-07-07 07:00::2008-08-08 08:00")
+##D sosCreateTime(sos = mySOS, time = "2007-07-07 07:00/2010-10-10 10:00")
+##D 
+##D sosCreateTime(sos = mySOS, time = "::2007-08-05")
+##D sosCreateTime(sos = mySOS, time = "2007-08-05/")
 ## End(Not run)
 
 
